.. _pecan_commands:

:mod:`pecan.commands` -- Pecan Commands
=======================================

The :mod:`pecan.commands` module implements the ``pecan`` console script
used to provide (for example) ``pecan serve`` and ``pecan shell`` command line
utilities.

.. automodule:: pecan.commands.base
  :members:
  :show-inheritance:

:mod:`pecan.commands.server` -- Pecan Development Server
++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: pecan.commands.serve
  :members:
  :show-inheritance:

:mod:`pecan.commands.shell` -- Pecan Interactive Shell
++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: pecan.commands.shell
  :members:
  :show-inheritance:
